# README #

## Fresenius Loader Project ##

This project defines a DB loader for the AWCBL functionality.
The m3-api server is loading on RabbitMq the records to be sent to the DB and this process is designed to take these records and save them on the DB.
The main reason is to remove the bottleneck from the m3-api server for the bulk load.
The m3-api server will validate the input files (CSV) and then load them in the RabbitMq, thus this process will take the queue and start to load it on the DB server.

### What is this repository for? ###

This project is responsible for

* Reading data via Message Queue
* store such data to the appropriate database

### How do I get set up? ###

* Clone this repository.
* In the folder where this is cloned, open a command prompt. Type:
> npm install
* Launch IntelliJ Ultimate (license required) with NodeJS plugin
* Create a "New Project with Existing Sources..."

### How do I run? ###

#### ENV VARS ####

* NODE_ENV = dev|qa|prod|test    (test = mocha tests)
* PORT = web port to listen

#### Multithreaded (requires server with more than one core) ####
* Splits duty in half by number of cores: Web and Queue Consumption
* If there's an odd number of cores, queue consumption takes the extra core
> node.exe master.js

#### Single core ####
* All on one core
> node.exe server.js 

### Configuration files ###
The application requires some configuration data.
Those data are stored in a file in a config file located in m3-loader/component/config.
The file is called : server.<env>.js
So for the QA environment will be server.qa.js.
A copy of the file is present in this repo but during the deployment such file is built by Chef using the template (see in the fresenius-infra repo) :
* chef/cookbooks/fresenius_base/templates/default/loader-config.json.erb
* chef/cookbooks/fresenius_base/recipes/web.rb

This repo has actually a file called server.prod.js but it will be never actually used since on PROD only a deployment is made.
No config file is directly loaded.

### How do I manage a cluster? ###

#### Signals ####

While the cluster manager is running, you can send signals.

*To reload workers - start new ones and shut down the old ones.

> kill -HUP MASTERPID

*To output to stdout number of workers and their PIDs

> kill -USR1 MASTERPID

*To increase running workers to the maximum number set at the start

> kill -USR2 MASTERPID

*To attempt graceful shutdown

> kill -TERM MASTERPID

### Who do I talk to? ###

* Stefano Bodini
* Ali Ataman

