
module.exports = function(sequelize, DataTypes) {
    var CatalogList = require("./catalogList")(sequelize, DataTypes);
    var ClinicCatalog = require("./clinicCatalog")(sequelize, DataTypes);
    var ClinicProfile = sequelize.define('ClinicProfile', {
            id: {
                type: DataTypes.INTEGER,
                field: 'id',
                primaryKey: true,
                autoIncrement: true
            },
            clinicId: {
                type: DataTypes.STRING,
                field: 'clinic_id'
            },
            vendorList: {
                type: DataTypes.VIRTUAL
            },
            catalogList: {
                type: DataTypes.VIRTUAL
            },
            mirceraVisible: {
                type: DataTypes.BOOLEAN,
                field: 'mircera_visible'
            },
            mirceraIo: {
                type: DataTypes.BOOLEAN,
                field: 'mircera_io'
            },
            areanespVisible: {
                type: DataTypes.BOOLEAN,
                field: 'areanesp_visible'
            },
            areanespIo: {
                type: DataTypes.BOOLEAN,
                field: 'areanesp_io'
            },
            epogenVisible: {
                type: DataTypes.BOOLEAN,
                field: 'epogen_visible'
            },
            epogenIo: {
                type: DataTypes.BOOLEAN,
                field: 'epogen_io'
            },
            retacritVisible: {
                type: DataTypes.BOOLEAN,
                field: 'retacrit_visible'
            },
            retacritIo: {
                type: DataTypes.BOOLEAN,
                field: 'retacrit_io'
            },
            countInEach: {
                type: DataTypes.BOOLEAN,
                field: 'count_in_each'
            },
            dateModified: {
                type: DataTypes.DATE,
                field: 'date_modified'
            },
            metro: {
                type: new DataTypes.VIRTUAL(DataTypes.BOOLEAN, ['vendorList']),
                get: function () {
                    if (!String.prototype.endsWith) {
                        String.prototype.endsWith = function(searchString, position) {
                            var subjectString = this.toString();
                            if (typeof position !== 'number' || !isFinite(position) || Math.floor(position) !== position || position > subjectString.length) {
                                position = subjectString.length;
                            }
                            position -= searchString.length;
                            var lastIndex = subjectString.indexOf(searchString, position);
                            return lastIndex !== -1 && lastIndex === position;
                        };
                    }
                    if (!String.prototype.startsWith) {
                        String.prototype.startsWith = function(searchString, position) {
                            position = position || 0;
                            return this.indexOf(searchString, position) === position;
                        };
                    }
                    return (this.get('vendorList') && (( new String(this.get('vendorList')).trim() == 'MM' ) ||
                    (new String(this.get('vendorList')).endsWith(",MM")) ||
                    (new String(this.get('vendorList')).startsWith("MM,")) ||
                    (new String(this.get('vendorList')).indexOf(",MM,") > -1)));
                }
            }
        },
        {
            timestamps: true,
            createdAt: false,
            deletedAt: false,
            updatedAt: 'dateModified',
            tableName: 'tbl_clinic_profile',
            indexes: [
                // Create a unique index on device timestamp
                {
                    unique: true,
                    fields: ['clinicId']
                },
            ]
        }
    );
    ClinicProfile.belongsToMany(CatalogList, { through: ClinicCatalog , as: 'Catalogs', foreignKey: 'clinicId', otherKey: 'catalogId'});
    return ClinicProfile;
};
